#include "math.h"
/*
    routine chkparms does a quick check on the validity of 
    parameters for an ARMA model.

    input:
    parms      double*       vector of length p+q containing 
			     the p AR coefficients followed by the
			     q MA coefficients
    p          int           order of the AR process
    q          int           order of the MA process

    output:
    returns  0 if the parameters appear ok, 1 if they are bad
*/
chkparms(double *parms,int p,int q)
{
  int i,bad;
  double d;

  bad = 0;
  for(i=0;i<p && bad == 0;i++){
	d = (double)choose(p,i + 1);
	if(fabs(parms[i]) >= d)bad = 1;
	}

  for(i=0;i<q && bad == 0;i++){
	d = (double)choose(q,i + 1);
	if(fabs(parms[p + i]) > d)bad = 1;
	}

  return(bad);
}
   
int choose(int n,int m)
{
   int i,c;

   if((m >= n) || (m <= 0))return(1);

   if(m < n - m)m = n - m;
   for(i=m+1,c=1;i<=n;i++)c *= i;
   c /= factorial(n - m);
   return(c);
}
/* factorial number function - only suitable for 
   small values of n (for larger values use a sum
   of logs and exponentiate at the end */

int factorial(int n)
{
  int i,f;

  if(n < 2)return(1);
  for(i=2,f=1;i<=n;i++)f *= i;
  return(f);
}
  
